@@ -2,7 +2,7 @@ var _ogre_shader_function_atom_8h =
 [
     [ "Ogre::RTShader::FunctionInvocation::FunctionInvocationCompare", "struct_ogre_1_1_r_t_shader_1_1_function_invocation_1_1_function_invocation_compare.html", "struct_ogre_1_1_r_t_shader_1_1_function_invocation_1_1_function_invocation_compare" ],
     [ "Ogre::RTShader::FunctionInvocation::FunctionInvocationLessThan", "struct_ogre_1_1_r_t_shader_1_1_function_invocation_1_1_function_invocation_less_than.html", "struct_ogre_1_1_r_t_shader_1_1_function_invocation_1_1_function_invocation_less_than" ],
-    [ "FunctionAtomInstanceList", "_ogre_shader_function_atom_8h.html#ga855704a7a01d33b5fbf134476a4506a8", null ],
-    [ "FunctionAtomInstanceIterator", "_ogre_shader_function_atom_8h.html#ga93c3d79b3386560226545b89126d507c", null ],
-    [ "FunctionAtomInstanceConstIterator", "_ogre_shader_function_atom_8h.html#gaac0a5ca5463f1d828d1c29d396e58e31", null ]
+    [ "Ogre::RTShader::FunctionAtomInstanceList", "group___r_t_shader.html#ga855704a7a01d33b5fbf134476a4506a8", null ],
+    [ "Ogre::RTShader::FunctionAtomInstanceIterator", "group___r_t_shader.html#ga93c3d79b3386560226545b89126d507c", null ],
+    [ "Ogre::RTShader::FunctionAtomInstanceConstIterator", "group___r_t_shader.html#gaac0a5ca5463f1d828d1c29d396e58e31", null ]
 ];
\ No newline at end of file
